Skip to contents

Downloads (if not already cached) and returns the yearly summary of 4-character OPCS-4 code usage with demographic breakdowns from 1st April 2012 onwards. Includes breakdowns by procedure type (all/main), sex, and age group. Restricted codes for which annual usage is not published have been removed.

start_date

Start date of code usage count

end_date

End date of code usage count

opcs4_code

The 4-character OPCS-4 code. Note that the punctuation from the code has been removed for compatibility with OpenCodelists.

description

Description of the OPCS-4 Code

breakdown

Type of breakdown: all_procedures, main_procedure, male, female, gender_unknown, or age groups (age_0, age_1_4, age_5_9, ..., age_85_89, age_90plus)

usage

Annual count of code usage. NA where suppressed due to small numbers.

Usage

get_hesapc_opcs4_breakdowns(version = NULL)

Arguments

version

String, dataset version, or NULL for the latest (default)

Value

A tibble

Examples

if (FALSE) { # \dontrun{
# Get sex breakdown for hip replacement procedures
get_hesapc_opcs4_breakdowns() |>
  dplyr::filter(grepl("hip replacement", description, ignore.case = TRUE)) |>
  dplyr::filter(breakdown %in% c("male", "female"))
} # }