Shows the cache directory location, the number and total size of cached datasets, and warns if the cache exceeds a recommended size limit.
Shows the cache directory location, the number and total size of cached datasets, and warns if the cache exceeds a recommended size limit.