Get yearly OPCS-4 procedure code usage from Hospital Episode Statistics Admitted Patient Care in England
Source:R/get-data.R
get_hesapc_opcs4.RdDownloads (if not already cached) and returns the yearly summary of 4-character OPCS-4 code usage from 1st April 2012 onwards. The code usage represents the total annual count of each procedure, recorded across the primary and the secondary procedure positions. Restricted codes for which annual usage is not published have been removed.
- start_date
Start date of code usage count
- end_date
End date of code usage count
- opcs4_code
The 4-character OPCS-4 code. Note that the punctuation from the code has been removed for compatibility with OpenCodelists.
- usage
Annual count of code usage.
- description
Description of the OPCS-4 Code